#!/bin/bash
# This is a script to build a Zenwalk package. Check the Zenwalk homepage: www.zenwalk.org
#
# SOFTWARE			: adeskbar
# MAINTAINER       	: skywatcher (s.skywatcher|AT|gmail|DOT|org, simone antoniucci)
# LATEST REVISION	: 2011-01-15
# BUILD-ONLY DEPS	: -
# NOTES				: -

### Checking for unbound variables and exit on errors
set -u -e

### Repo
URL=http://zenwalk.pinguix.com/user-accounts/skywatcher

### Pkg variables
NAME="adeskbar"
VERSION="0.4.2"
ARCH="i686"
CPU="i686"
BUILD="70.1"
EXT="txz"
HOMEPAGE="http://www.ad-comp.be/index.php?category/ADesk-Bar"
SRCLNK="http://www.ad-comp.be/public/projets/ADeskBar/${NAME}-$VERSION.tar.bz2"
DESCRIPTION="a quick application launcher"
DOCS="README"
ADDSRC=""
INCSRC=""
ADDDEP="python,pygtk,gtk+2,pycairo,gnome-python-desktop,vte,pyalsaaudio,gnome-icon-theme,gnome-menus"
XCLDEP=""

### Script variables
CWD=`pwd`
PKG=$NAME-$VERSION-$ARCH-$BUILD
URL=$URL/$NAME/$VERSION
PKGDIR=$CWD/$NAME-install
SRCDIR=$CWD/$NAME-$VERSION
SRCPKG=`echo $SRCLNK | cut -d\  -f1 | rev | cut -d/ -f1 | rev`

### Flags and jobs
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
NJOBS="-j4"

### Cleaning
rm -rf $PKGDIR
rm -rf $SRCDIR

### Making default package dirs
install -dv $SRCDIR $PKGDIR/{install,usr/src/$NAME-$VERSION}

### Getting sources
for src in $SRCLNK; do \
	source=`echo $src | rev | cut -d/ -f1 | rev` 
	if [ -f $source ]; then
		echo "Source file $source is already present, no need to download it";
	else
		echo "Downloading $source..."
		wget -c -nv $SRCLNK
	fi
done

### Extracting main sources
tar xfv $SRCPKG -C $SRCDIR --strip-components=1

### Building ===========================================================
cd $SRCDIR

# Repackaging
install -dv $PKGDIR/usr/share/$NAME
cp -a ./src/* $PKGDIR/usr/share/$NAME
install -dv $PKGDIR/usr/bin
cat $SRCDIR/adeskbar.sh > $PKGDIR/usr/bin/$NAME
chmod 755 $PKGDIR/usr/bin/$NAME

# Icon
install -Dv $SRCDIR/src/images/adeskbar.png $PKGDIR/usr/share/icons/hicolor/128x128/apps/adeskbar.png
install -Dv $SRCDIR/src/images/adeskbar.png $PKGDIR/usr/share/icons/hicolor/48x48/apps/adeskbar.png
mogrify -resize 48x48 $PKGDIR/usr/share/icons/hicolor/48x48/apps/adeskbar.png

# Desktop entry
install -Dv $SRCDIR/adeskbar.desktop $PKGDIR/usr/share/applications/adeskbar.desktop
sed -i "s:Categories=GNOME;Utility;:Categories=Utility;GNOME;:" $PKGDIR/usr/share/applications/adeskbar.desktop
sed -i "s:NoDisplay=true::" $PKGDIR/usr/share/applications/adeskbar.desktop

# Docs, man, info
install -dv $PKGDIR/usr/doc/$NAME-$VERSION
install -v $DOCS $PKGDIR/usr/doc/$NAME-$VERSION

# Unnedeed stuff

### Slack-desc 
#    |-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc << EOF
$NAME: $NAME - $DESCRIPTION
$NAME:  
$NAME: AdeskBar is a quick and lightweight application launcher bar written
$NAME: in python.
$NAME: 
$NAME: 
$NAME: 
$NAME: 
$NAME: 
$NAME: 
$NAME: $HOMEPAGE
EOF

### Doinstall

## dotnew

## infodir 

## mime & desktop 

## scrollkeeper

# ====================================================================== 

### Managing and zipping man and info files
if [ -d $PKGDIR/usr/man ]; then
	find $PKGDIR/usr/man -type f -exec gzip -9 -v {} \;
fi
if [ -d $PKGDIR/usr/info ]; then
	find $PKGDIR/usr/info -type f -exec gzip -9 -v {} \;
fi

### Adding build-file and included stuff to the package
for file in $0 $INCSRC
	do cp -av $CWD/$file $PKGDIR/usr/src/$NAME-$VERSION
done
chmod a+x $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh

### Stripping binaries
cd $PKGDIR
set +e
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

### Ownerships and permissions
cd $PKGDIR
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
set -e

### Special permissions

### Making the package
makepkg -l y -c n $CWD/$PKG.$EXT
cd $CWD

### md5
md5sum $PKG.$EXT > $PKG.md5

### dep
ADD=$ADDDEP EXCLUDE=$XCLDEP requiredbuilder -z -c $PKG.$EXT > $PKG.dep

### slackdesc
cat $PKGDIR/install/slack-desc > $PKG.txt

### src
echo $SRCLNK > $PKG.src
for link in $0 $ADDSRC 
	do echo $URL/$link >> $PKG.src
done

### Cleaning
rm -rf $SRCDIR
rm -rf $PKGDIR

### Done. Ciao!
